package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.bcel.classfile.ArrayElementValue;
import org.apache.bcel.classfile.ElementValue;

public class ArrayElementValueGen extends ElementValueGen {
   private final List<ElementValueGen> evalues;

   public ArrayElementValueGen(ArrayElementValue value, ConstantPoolGen cpool, boolean copyPoolEntries) {
      super(91, cpool);
      this.evalues = new ArrayList();
      ElementValue[] in = value.getElementValuesArray();
      ElementValue[] var5 = in;
      int var6 = in.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         ElementValue element = var5[var7];
         this.evalues.add(ElementValueGen.copy(element, cpool, copyPoolEntries));
      }

   }

   public ArrayElementValueGen(ConstantPoolGen cp) {
      super(91, cp);
      this.evalues = new ArrayList();
   }

   public ArrayElementValueGen(int type, ElementValue[] datums, ConstantPoolGen cpool) {
      super(type, cpool);
      if (type != 91) {
         throw new IllegalArgumentException("Only element values of type array can be built with this ctor - type specified: " + type);
      } else {
         this.evalues = new ArrayList();
         ElementValue[] var4 = datums;
         int var5 = datums.length;

         for(int var6 = 0; var6 < var5; ++var6) {
            ElementValue datum = var4[var6];
            this.evalues.add(ElementValueGen.copy(datum, cpool, true));
         }

      }
   }

   public void addElement(ElementValueGen gen) {
      this.evalues.add(gen);
   }

   public void dump(DataOutputStream dos) throws IOException {
      dos.writeByte(super.getElementValueType());
      dos.writeShort(this.evalues.size());
      Iterator var2 = this.evalues.iterator();

      while(var2.hasNext()) {
         ElementValueGen element = (ElementValueGen)var2.next();
         element.dump(dos);
      }

   }

   public ElementValue getElementValue() {
      ElementValue[] immutableData = new ElementValue[this.evalues.size()];
      int i = 0;

      ElementValueGen element;
      for(Iterator var3 = this.evalues.iterator(); var3.hasNext(); immutableData[i++] = element.getElementValue()) {
         element = (ElementValueGen)var3.next();
      }

      return new ArrayElementValue(super.getElementValueType(), immutableData, this.getConstantPool().getConstantPool());
   }

   public List<ElementValueGen> getElementValues() {
      return this.evalues;
   }

   public int getElementValuesSize() {
      return this.evalues.size();
   }

   public String stringifyValue() {
      StringBuilder sb = new StringBuilder();
      sb.append("[");
      String comma = "";
      Iterator var3 = this.evalues.iterator();

      while(var3.hasNext()) {
         ElementValueGen element = (ElementValueGen)var3.next();
         sb.append(comma);
         comma = ",";
         sb.append(element.stringifyValue());
      }

      sb.append("]");
      return sb.toString();
   }
}
